summaryrefslogtreecommitdiff
path: root/slang.h
diff options
context:
space:
mode:
Diffstat (limited to 'slang.h')
-rw-r--r--slang.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/slang.h b/slang.h
index d11c4b7f2..233b418c3 100644
--- a/slang.h
+++ b/slang.h
@@ -2102,16 +2102,16 @@ extern "C"
SLANG_API SlangUInt spReflection_getHashedStringCount(
SlangReflection* reflection);
- /// Get a hashed string. The number of chars is writtent in outCount. Note the count does *NOT* including terminating 0,
- /// and the returned pointer will not generally have a terminating zero.
+ /// Get a hashed string. The number of chars is written in outCount.
+ /// The count does *NOT* including terminating 0. The returned string will be 0 terminated.
SLANG_API const char* spReflection_getHashedString(
SlangReflection* reflection,
SlangUInt index,
size_t* outCount);
- /// Calculate a string hash.
- // Count should *NOT* include terminating zero.
- SLANG_API int spCalcStringHash(const char* chars, size_t count);
+ /// Compute a string hash.
+ /// Count should *NOT* include terminating zero.
+ SLANG_API int spComputeStringHash(const char* chars, size_t count);
#ifdef __cplusplus
}